@@ -8,32 +8,30 @@ Endpoint implementations of various SSH interactions.
 
 __all__ = ["AuthenticationFailed", "SSHCommandAddress", "SSHCommandClientEndpoint"]
 
-from struct import unpack
-from os.path import expanduser
-
 import signal
+from os.path import expanduser
+from struct import unpack
 
 from zope.interface import Interface, implementer
 
-from twisted.logger import Logger
-from twisted.python.compat import nativeString, networkString
-from twisted.python.filepath import FilePath
-from twisted.python.failure import Failure
+from twisted.conch.client.agent import SSHAgentClient
+from twisted.conch.client.default import _KNOWN_HOSTS
+from twisted.conch.client.knownhosts import ConsoleUI, KnownHostsFile
+from twisted.conch.ssh.channel import SSHChannel
+from twisted.conch.ssh.common import NS, getNS
+from twisted.conch.ssh.connection import SSHConnection
+from twisted.conch.ssh.keys import Key
+from twisted.conch.ssh.transport import SSHClientTransport
+from twisted.conch.ssh.userauth import SSHUserAuthClient
+from twisted.internet.defer import CancelledError, Deferred, succeed
+from twisted.internet.endpoints import TCP4ClientEndpoint, connectProtocol
 from twisted.internet.error import ConnectionDone, ProcessTerminated
 from twisted.internet.interfaces import IStreamClientEndpoint
 from twisted.internet.protocol import Factory
-from twisted.internet.defer import Deferred, succeed, CancelledError
-from twisted.internet.endpoints import TCP4ClientEndpoint, connectProtocol
-
-from twisted.conch.ssh.keys import Key
-from twisted.conch.ssh.common import getNS, NS
-from twisted.conch.ssh.transport import SSHClientTransport
-from twisted.conch.ssh.connection import SSHConnection
-from twisted.conch.ssh.userauth import SSHUserAuthClient
-from twisted.conch.ssh.channel import SSHChannel
-from twisted.conch.client.knownhosts import ConsoleUI, KnownHostsFile
-from twisted.conch.client.agent import SSHAgentClient
-from twisted.conch.client.default import _KNOWN_HOSTS
+from twisted.logger import Logger
+from twisted.python.compat import nativeString, networkString
+from twisted.python.failure import Failure
+from twisted.python.filepath import FilePath
 
 
 class AuthenticationFailed(Exception):
@@ -228,7 +226,7 @@ class _CommandChannel(SSHChannel):
         coreDumped, data = bool(ord(data[0:1])), data[1:]
         errorMessage, data = getNS(data)
         languageTag, data = getNS(data)
-        signalName = "SIG{}".format(nativeString(shortSignalName))
+        signalName = f"SIG{nativeString(shortSignalName)}"
         signalID = getattr(signal, signalName, -1)
         self._log.info(
             "Process exited with signal {shortSignalName!r};"
