@@ -5,31 +5,35 @@
 """
 Some fairly inadequate testcases for Twisted XML support.
 """
+from __future__ import annotations
 
+from importlib import reload
 from io import BytesIO
 
+from typing_extensions import Literal
+
 from twisted.trial.unittest import TestCase
-from twisted.web import sux
-from twisted.web import microdom
-from twisted.web import domhelpers
+from twisted.web import domhelpers, microdom, sux
 
 
 class Sux0r(sux.XMLParser):
-    def __init__(self):
-        self.tokens = []
+    def __init__(self) -> None:
+        self.tokens: list[
+            tuple[Literal["start"], str, dict[str, str]] | tuple[Literal["text"], str]
+        ] = []
 
-    def getTagStarts(self):
+    def getTagStarts(self) -> list[tuple[Literal["start"], str, dict[str, str]]]:
         return [token for token in self.tokens if token[0] == "start"]
 
-    def gotTagStart(self, name, attrs):
+    def gotTagStart(self, name: str, attrs: dict[str, str]) -> None:
         self.tokens.append(("start", name, attrs))
 
-    def gotText(self, text):
+    def gotText(self, text: str) -> None:
         self.tokens.append(("text", text))
 
 
 class SUXTests(TestCase):
-    def test_bork(self):
+    def test_bork(self) -> None:
         s = b"<bork><bork><bork>"
         ms = Sux0r()
         ms.connectionMade()
@@ -38,7 +42,7 @@ class SUXTests(TestCase):
 
 
 class MicroDOMTests(TestCase):
-    def test_leadingTextDropping(self):
+    def test_leadingTextDropping(self) -> None:
         """
         Make sure that if there's no top-level node lenient-mode won't
         drop leading text that's outside of any elements.
@@ -54,7 +58,7 @@ class MicroDOMTests(TestCase):
             byteStream.getvalue(), b"<html>Hi orders! <br />Well. <br /></html>"
         )
 
-    def test_trailingTextDropping(self):
+    def test_trailingTextDropping(self) -> None:
         """
         Ensure that no *trailing* text in a mal-formed
         no-top-level-element document(s) will not be dropped.
@@ -66,7 +70,7 @@ class MicroDOMTests(TestCase):
         d.firstChild().writexml(byteStream, "", "", "", "", {}, "")
         self.assertEqual(byteStream.getvalue(), b"<html><br />Hi orders!</html>")
 
-    def test_noTags(self):
+    def test_noTags(self) -> None:
         """
         A string with nothing that looks like a tag at all should just
         be parsed as body text.
@@ -75,7 +79,7 @@ class MicroDOMTests(TestCase):
         d = microdom.parseString(s, beExtremelyLenient=True)
         self.assertEqual(d.firstChild().toxml(), "<html>Hi orders!</html>")
 
-    def test_surroundingCrap(self):
+    def test_surroundingCrap(self) -> None:
         """
         If a document is surrounded by non-xml text, the text should
         be remain in the XML.
@@ -84,7 +88,7 @@ class MicroDOMTests(TestCase):
         d = microdom.parseString(s, beExtremelyLenient=True)
         self.assertEqual(d.firstChild().toxml(), "<html>Hi<br /> orders!</html>")
 
-    def test_caseSensitiveSoonCloser(self):
+    def test_caseSensitiveSoonCloser(self) -> None:
         s = """
               <HTML><BODY>
               <P ALIGN="CENTER">
@@ -102,7 +106,7 @@ class MicroDOMTests(TestCase):
         n = domhelpers.gatherTextNodes(l[0], 1).replace("&nbsp;", " ")
         self.assertEqual(n.find("insane"), -1)
 
-    def test_lenientParenting(self):
+    def test_lenientParenting(self) -> None:
         """
         Test that C{parentNode} attributes are set to meaningful values when
         we are parsing HTML that lacks a root node.
@@ -114,7 +118,7 @@ class MicroDOMTests(TestCase):
             d.documentElement, d.documentElement.firstChild().parentNode
         )
 
-    def test_lenientParentSingle(self):
+    def test_lenientParentSingle(self) -> None:
         """
         Test that the C{parentNode} attribute is set to a meaningful value
         when we parse an HTML document that has a non-Element root node.
@@ -125,7 +129,7 @@ class MicroDOMTests(TestCase):
             d.documentElement, d.documentElement.firstChild().parentNode
         )
 
-    def test_unEntities(self):
+    def test_unEntities(self) -> None:
         s = """
                 <HTML>
                     This HTML goes between Stupid <=CrAzY!=> Dumb.
@@ -135,10 +139,10 @@ class MicroDOMTests(TestCase):
         n = domhelpers.gatherTextNodes(d)
         self.assertNotEqual(n.find(">"), -1)
 
-    def test_emptyError(self):
+    def test_emptyError(self) -> None:
         self.assertRaises(sux.ParseError, microdom.parseString, "")
 
-    def test_tameDocument(self):
+    def test_tameDocument(self) -> None:
         s = """
         <test>
          <it>
@@ -153,7 +157,7 @@ class MicroDOMTests(TestCase):
         d = microdom.parseString(s)
         self.assertEqual(domhelpers.gatherTextNodes(d.documentElement).strip(), "test")
 
-    def test_awfulTagSoup(self):
+    def test_awfulTagSoup(self) -> None:
         s = """
         <html>
         <head><title> I send you this message to have your advice!!!!</titl e
@@ -179,7 +183,7 @@ alert("I hate you");
         l = domhelpers.findNodesNamed(d.documentElement, "blink")
         self.assertEqual(len(l), 1)
 
-    def test_scriptLeniency(self):
+    def test_scriptLeniency(self) -> None:
         s = """
         <script>(foo < bar) and (bar > foo)</script>
         <script language="javascript">foo </scrip bar </script>
@@ -196,7 +200,7 @@ alert("I hate you");
             "foo </scrip bar ",
         )
 
-    def test_scriptLeniencyIntelligence(self):
+    def test_scriptLeniencyIntelligence(self) -> None:
         # if there is comment or CDATA in script, the autoquoting in bEL mode
         # should not happen
         s = """<script><!-- lalal --></script>"""
@@ -214,7 +218,7 @@ alert("I hate you");
             microdom.parseString(s, beExtremelyLenient=1).firstChild().toxml(), s
         )
 
-    def test_preserveCase(self):
+    def test_preserveCase(self) -> None:
         s = "<eNcApSuLaTe><sUxor></sUxor><bOrk><w00T>TeXt</W00t></BoRk></EnCaPsUlAtE>"
         s2 = s.lower().replace("text", "TeXt")
         # these are the only two option permutations that *can* parse the above
@@ -230,41 +234,33 @@ alert("I hate you");
         # however this assertion tests preserving case for start and
         # end tags while still matching stuff like <bOrk></BoRk>
         self.assertEqual(d.documentElement.toxml(), s)
-        self.assertTrue(
-            d.isEqualToDocument(d2), "{!r} != {!r}".format(d.toxml(), d2.toxml())
-        )
-        self.assertTrue(
-            d2.isEqualToDocument(d3), "{!r} != {!r}".format(d2.toxml(), d3.toxml())
-        )
+        self.assertTrue(d.isEqualToDocument(d2), f"{d.toxml()!r} != {d2.toxml()!r}")
+        self.assertTrue(d2.isEqualToDocument(d3), f"{d2.toxml()!r} != {d3.toxml()!r}")
         # caseInsensitive=0 on the left, NOT perserveCase=1 on the right
         ## XXX THIS TEST IS TURNED OFF UNTIL SOMEONE WHO CARES ABOUT FIXING IT DOES
         # self.assertFalse(d3.isEqualToDocument(d2), "%r == %r" % (d3.toxml(), d2.toxml()))
-        self.assertTrue(
-            d3.isEqualToDocument(d4), "{!r} != {!r}".format(d3.toxml(), d4.toxml())
-        )
-        self.assertTrue(
-            d4.isEqualToDocument(d5), "{!r} != {!r}".format(d4.toxml(), d5.toxml())
-        )
+        self.assertTrue(d3.isEqualToDocument(d4), f"{d3.toxml()!r} != {d4.toxml()!r}")
+        self.assertTrue(d4.isEqualToDocument(d5), f"{d4.toxml()!r} != {d5.toxml()!r}")
 
-    def test_differentQuotes(self):
+    def test_differentQuotes(self) -> None:
         s = "<test a=\"a\" b='b' />"
         d = microdom.parseString(s)
         e = d.documentElement
         self.assertEqual(e.getAttribute("a"), "a")
         self.assertEqual(e.getAttribute("b"), "b")
 
-    def test_Linebreaks(self):
+    def test_Linebreaks(self) -> None:
         s = '<test \na="a"\n\tb="#b" />'
         d = microdom.parseString(s)
         e = d.documentElement
         self.assertEqual(e.getAttribute("a"), "a")
         self.assertEqual(e.getAttribute("b"), "#b")
 
-    def test_mismatchedTags(self):
+    def test_mismatchedTags(self) -> None:
         for s in "<test>", "<test> </tset>", "</test>":
             self.assertRaises(microdom.MismatchedTags, microdom.parseString, s)
 
-    def test_comment(self):
+    def test_comment(self) -> None:
         s = "<bar><!--<foo />--></bar>"
         d = microdom.parseString(s)
         e = d.documentElement
@@ -276,7 +272,7 @@ alert("I hate you");
         self.assertTrue(c is not c2)
         self.assertEqual(c2.toxml(), "<!--<foo />-->")
 
-    def test_text(self):
+    def test_text(self) -> None:
         d = microdom.parseString("<bar>xxxx</bar>").documentElement
         text = d.childNodes[0]
         self.assertTrue(isinstance(text, microdom.Text))
@@ -285,7 +281,7 @@ alert("I hate you");
         self.assertTrue(clone is not text)
         self.assertEqual(clone.toxml(), "xxxx")
 
-    def test_entities(self):
+    def test_entities(self) -> None:
         nodes = microdom.parseString("<b>&amp;&#12AB;</b>").documentElement.childNodes
         self.assertEqual(len(nodes), 2)
         self.assertEqual(nodes[0].data, "&amp;")
@@ -294,25 +290,25 @@ alert("I hate you");
         for n in nodes:
             self.assertTrue(isinstance(n, microdom.EntityReference))
 
-    def test_CData(self):
+    def test_CData(self) -> None:
         s = "<x><![CDATA[</x>\r\n & foo]]></x>"
         cdata = microdom.parseString(s).documentElement.childNodes[0]
         self.assertTrue(isinstance(cdata, microdom.CDATASection))
         self.assertEqual(cdata.data, "</x>\r\n & foo")
         self.assertEqual(cdata.cloneNode().toxml(), "<![CDATA[</x>\r\n & foo]]>")
 
-    def test_singletons(self):
+    def test_singletons(self) -> None:
         s = "<foo><b/><b /><b\n/></foo>"
         s2 = "<foo><b/><b/><b/></foo>"
         nodes = microdom.parseString(s).documentElement.childNodes
         nodes2 = microdom.parseString(s2).documentElement.childNodes
         self.assertEqual(len(nodes), 3)
-        for (n, n2) in zip(nodes, nodes2):
+        for n, n2 in zip(nodes, nodes2):
             self.assertTrue(isinstance(n, microdom.Element))
             self.assertEqual(n.nodeName, "b")
             self.assertTrue(n.isEqualToNode(n2))
 
-    def test_attributes(self):
+    def test_attributes(self) -> None:
         s = '<foo a="b" />'
         node = microdom.parseString(s).documentElement
 
@@ -326,7 +322,7 @@ alert("I hate you");
         node.setAttribute("foo", "bar")
         self.assertEqual(node.getAttribute("foo"), "bar")
 
-    def test_children(self):
+    def test_children(self) -> None:
         s = "<foo><bar /><baz /><bax>foo</bax></foo>"
         d = microdom.parseString(s).documentElement
         self.assertEqual([n.nodeName for n in d.childNodes], ["bar", "baz", "bax"])
@@ -335,7 +331,7 @@ alert("I hate you");
         self.assertTrue(d.hasChildNodes())
         self.assertTrue(not d.firstChild().hasChildNodes())
 
-    def test_mutate(self):
+    def test_mutate(self) -> None:
         s = "<foo />"
         s1 = '<foo a="b"><bar/><foo/></foo>'
         s2 = '<foo a="b">foo</foo>'
@@ -365,7 +361,7 @@ alert("I hate you");
         self.assertEqual(d.firstChild(), t)
         self.assertTrue(d.isEqualToNode(d2))
 
-    def test_replaceNonChild(self):
+    def test_replaceNonChild(self) -> None:
         """
         L{Node.replaceChild} raises L{ValueError} if the node given to be
         replaced is not a child of the node C{replaceChild} is called on.
@@ -376,7 +372,7 @@ alert("I hate you");
 
         self.assertRaises(ValueError, parent.replaceChild, replacement, orphan)
 
-    def test_search(self):
+    def test_search(self) -> None:
         s = "<foo><bar id='me' /><baz><foo /></baz></foo>"
         s2 = "<fOo><bAr id='me' /><bAz><fOO /></bAz></fOo>"
         d = microdom.parseString(s)
@@ -406,7 +402,7 @@ alert("I hate you");
             d3.getElementsByTagName("fOo"), [root, root.lastChild().firstChild()]
         )
 
-    def test_doctype(self):
+    def test_doctype(self) -> None:
         s = (
             '<?xml version="1.0"?>'
             '<!DOCTYPE foo PUBLIC "baz" "http://www.example.com/example.dtd">'
@@ -429,7 +425,7 @@ alert("I hate you");
         ("<foo>hello there &amp; yoyoy</foo>", "<foo>hello there &amp; yoyoy</foo>"),
     ]
 
-    def test_output(self):
+    def test_output(self) -> None:
         for s, out in self.samples:
             d = microdom.parseString(s, caseInsensitive=0)
             d2 = microdom.parseString(out, caseInsensitive=0)
@@ -437,11 +433,11 @@ alert("I hate you");
             self.assertEqual(out, testOut)
             self.assertTrue(d.isEqualToDocument(d2))
 
-    def test_errors(self):
+    def test_errors(self) -> None:
         for s in ["<foo>&am</foo>", "<foo", "<f>&</f>", "<() />"]:
             self.assertRaises(Exception, microdom.parseString, s)
 
-    def test_caseInsensitive(self):
+    def test_caseInsensitive(self) -> None:
         s = "<foo a='b'><BAx>x</bax></FOO>"
         s2 = '<foo a="b"><bax>x</bax></foo>'
         s3 = "<FOO a='b'><BAx>x</BAx></FOO>"
@@ -464,7 +460,7 @@ alert("I hate you");
         self.assertEqual(d4.documentElement.toxml(), '<foo A="b">x</foo>')
         self.assertEqual(d5.documentElement.toxml(), '<foo a="b">x</foo>')
 
-    def test_eatingWhitespace(self):
+    def test_eatingWhitespace(self) -> None:
         s = """<hello>
         </hello>"""
         d = microdom.parseString(s)
@@ -473,7 +469,7 @@ alert("I hate you");
         )
         self.assertTrue(d.isEqualToDocument(microdom.parseString("<hello></hello>")))
 
-    def test_lenientAmpersand(self):
+    def test_lenientAmpersand(self) -> None:
         prefix = "<?xml version='1.0'?>"
         # we use <pre> so space will be preserved
         for i, o in [
@@ -482,36 +478,34 @@ alert("I hate you");
             ("&amp;", "&amp;"),
             ("&hello monkey", "&amp;hello monkey"),
         ]:
-            d = microdom.parseString(
-                "{}<pre>{}</pre>".format(prefix, i), beExtremelyLenient=1
-            )
+            d = microdom.parseString(f"{prefix}<pre>{i}</pre>", beExtremelyLenient=1)
             self.assertEqual(d.documentElement.toxml(), "<pre>%s</pre>" % o)
         # non-space preserving
         d = microdom.parseString("<t>hello & there</t>", beExtremelyLenient=1)
         self.assertEqual(d.documentElement.toxml(), "<t>hello &amp; there</t>")
 
-    def test_insensitiveLenient(self):
+    def test_insensitiveLenient(self) -> None:
         # testing issue #537
         d = microdom.parseString(
             "<?xml version='1.0'?><bar><xA><y>c</Xa> <foo></bar>", beExtremelyLenient=1
         )
         self.assertEqual(d.documentElement.firstChild().toxml(), "<xa><y>c</y></xa>")
 
-    def test_laterCloserSimple(self):
+    def test_laterCloserSimple(self) -> None:
         s = "<ul><li>foo<li>bar<li>baz</ul>"
         d = microdom.parseString(s, beExtremelyLenient=1)
         expected = "<ul><li>foo</li><li>bar</li><li>baz</li></ul>"
         actual = d.documentElement.toxml()
         self.assertEqual(expected, actual)
 
-    def test_laterCloserCaseInsensitive(self):
+    def test_laterCloserCaseInsensitive(self) -> None:
         s = "<DL><p><DT>foo<DD>bar</DL>"
         d = microdom.parseString(s, beExtremelyLenient=1)
         expected = "<dl><p></p><dt>foo</dt><dd>bar</dd></dl>"
         actual = d.documentElement.toxml()
         self.assertEqual(expected, actual)
 
-    def test_laterCloserDL(self):
+    def test_laterCloserDL(self) -> None:
         s = (
             "<dl>"
             "<dt>word<dd>definition"
@@ -528,7 +522,7 @@ alert("I hate you");
         actual = d.documentElement.toxml()
         self.assertEqual(expected, actual)
 
-    def test_unicodeTolerance(self):
+    def test_unicodeTolerance(self) -> None:
         import struct
 
         s = "<foo><bar><baz /></bar></foo>"
@@ -546,7 +540,7 @@ alert("I hate you");
             b"\x00>\x00<\x00/\x00J\x00A\x00P\x00A\x00N\x00E\x00S\x00E\x00>\x00"
         )
 
-        def reverseBytes(s):
+        def reverseBytes(s: bytes) -> bytes:
             fmt = str(len(s) // 2) + "H"
             return struct.pack("<" + fmt, *struct.unpack(">" + fmt, s))
 
@@ -573,7 +567,7 @@ alert("I hate you");
             j3.toxml(), (hdr + "<foo><div>\u221a</div><!--\u221a--></foo>")
         )
 
-    def test_namedChildren(self):
+    def test_namedChildren(self) -> None:
         tests = {
             "<foo><bar /><bar unf='1' /><bar>asdfadsf</bar>" "<bam/></foo>": 3,
             "<foo>asdf</foo>": 0,
@@ -586,7 +580,7 @@ alert("I hate you");
             if result:
                 self.assertTrue(hasattr(result[0], "tagName"))
 
-    def test_cloneNode(self):
+    def test_cloneNode(self) -> None:
         s = '<foo a="b"><bax>x</bax></foo>'
         node = microdom.parseString(s).documentElement
         clone = node.cloneNode(deep=1)
@@ -599,7 +593,7 @@ alert("I hate you");
         self.assertEqual(s, clone.toxml())
         self.assertEqual(node.namespace, clone.namespace)
 
-    def test_cloneDocument(self):
+    def test_cloneDocument(self) -> None:
         s = (
             '<?xml version="1.0"?>'
             '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"'
@@ -615,7 +609,7 @@ alert("I hate you");
         self.assertTrue(clone.isEqualToDocument(node))
         self.assertTrue(node.isEqualToDocument(clone))
 
-    def test_LMX(self):
+    def test_LMX(self) -> None:
         n = microdom.Element("p")
         lmx = microdom.lmx(n)
         lmx.text("foo")
@@ -627,14 +621,14 @@ alert("I hate you");
         s = '<p>foo<b a="c"><foo z="foo"></foo><foo></foo><bar c="y"></bar></b></p>'
         self.assertEqual(s, n.toxml())
 
-    def test_dict(self):
+    def test_dict(self) -> None:
         """
         Returns a dictionary which is hashable.
         """
         n = microdom.Element("p")
         hash(n)
 
-    def test_escaping(self):
+    def test_escaping(self) -> None:
         # issue 590
         raw = "&'some \"stuff\"', <what up?>"
         cooked = "&amp;'some &quot;stuff&quot;', &lt;what up?&gt;"
@@ -642,7 +636,7 @@ alert("I hate you");
         self.assertEqual(esc1, cooked)
         self.assertEqual(microdom.unescape(esc1), raw)
 
-    def test_namespaces(self):
+    def test_namespaces(self) -> None:
         s = """
         <x xmlns="base">
         <y />
@@ -674,7 +668,7 @@ alert("I hate you");
             "1",
         )
 
-    def test_namespaceDelete(self):
+    def test_namespaceDelete(self) -> None:
         """
         Test that C{toxml} can support xml structures that remove namespaces.
         """
@@ -685,7 +679,7 @@ alert("I hate you");
         s2 = microdom.parseString(s1).toxml()
         self.assertEqual(s1, s2)
 
-    def test_namespaceInheritance(self):
+    def test_namespaceInheritance(self) -> None:
         """
         Check that unspecified namespace is a thing separate from undefined
         namespace. This test added after discovering some weirdness in Lore.
@@ -698,7 +692,7 @@ alert("I hate you");
             parent.toxml(), '<div xmlns="http://www.w3.org/1999/xhtml"><ol></ol></div>'
         )
 
-    def test_prefixedTags(self):
+    def test_prefixedTags(self) -> None:
         """
         XML elements with a prefixed name as per upper level tag definition
         have a start-tag of C{"<prefix:tag>"} and an end-tag of
@@ -741,7 +735,7 @@ alert("I hate you");
         xmlOut = document.toxml()
         self.assertEqual(xmlOut, xmlOk)
 
-    def test_prefixPropagation(self):
+    def test_prefixPropagation(self) -> None:
         """
         Children of prefixed tags respect the default namespace at the point
         where they are rendered.  Specifically, they are not influenced by the
@@ -800,6 +794,18 @@ alert("I hate you");
         xmlOut = document.toxml()
         self.assertEqual(xmlOut, xmlOk)
 
+    def test_deprecation(self) -> None:
+        """
+        An import will raise the deprecation warning.
+        """
+        reload(microdom)
+        warnings = self.flushWarnings([self.test_deprecation])
+        self.assertEqual(1, len(warnings))
+        self.assertEqual(
+            "twisted.web.microdom was deprecated at Twisted 23.10.0",
+            warnings[0]["message"],
+        )
+
 
 class BrokenHTMLTests(TestCase):
     """
@@ -810,7 +816,9 @@ class BrokenHTMLTests(TestCase):
     bad HTML.
     """
 
-    def checkParsed(self, input, expected, beExtremelyLenient=1):
+    def checkParsed(
+        self, input: str, expected: str, beExtremelyLenient: int = 1
+    ) -> None:
         """
         Check that C{input}, when parsed, produces a DOM where the XML
         of the document element is equal to C{expected}.
@@ -818,7 +826,7 @@ class BrokenHTMLTests(TestCase):
         output = microdom.parseString(input, beExtremelyLenient=beExtremelyLenient)
         self.assertEqual(output.documentElement.toxml(), expected)
 
-    def test_brokenAttributeName(self):
+    def test_brokenAttributeName(self) -> None:
         """
         Check that microdom does its best to handle broken attribute names.
         The important thing is that it doesn't raise an exception.
@@ -827,7 +835,7 @@ class BrokenHTMLTests(TestCase):
         expected = '<body><h1><div al="True" ign="center">' "Foo</div></h1></body>"
         self.checkParsed(input, expected)
 
-    def test_brokenAttributeValue(self):
+    def test_brokenAttributeValue(self) -> None:
         """
         Check that microdom encompasses broken attribute values.
         """
@@ -835,7 +843,7 @@ class BrokenHTMLTests(TestCase):
         expected = '<body><h1><div align="cen!\n ter">Foo</div></h1></body>'
         self.checkParsed(input, expected)
 
-    def test_brokenOpeningTag(self):
+    def test_brokenOpeningTag(self) -> None:
         """
         Check that microdom does its best to handle broken opening tags.
         The important thing is that it doesn't raise an exception.
@@ -844,7 +852,7 @@ class BrokenHTMLTests(TestCase):
         expected = '<body><h1><sp an="True">Hello World!</sp></h1></body>'
         self.checkParsed(input, expected)
 
-    def test_brokenSelfClosingTag(self):
+    def test_brokenSelfClosingTag(self) -> None:
         """
         Check that microdom does its best to handle broken self-closing tags
         The important thing is that it doesn't raise an exception.
@@ -852,7 +860,7 @@ class BrokenHTMLTests(TestCase):
         self.checkParsed("<body><span /!\n></body>", "<body><span></span></body>")
         self.checkParsed("<span!\n />", "<span></span>")
 
-    def test_brokenClosingTag(self):
+    def test_brokenClosingTag(self) -> None:
         """
         Check that microdom does its best to handle broken closing tags.
         The important thing is that it doesn't raise an exception.
@@ -874,7 +882,7 @@ class NodeTests(TestCase):
     Tests for L{Node}.
     """
 
-    def test_isNodeEqualTo(self):
+    def test_isNodeEqualTo(self) -> None:
         """
         L{Node.isEqualToNode} returns C{True} if and only if passed a L{Node}
         with the same children.
@@ -901,7 +909,7 @@ class NodeTests(TestCase):
         another.firstChild().appendChild(microdom.Node(object()))
         self.assertTrue(node.isEqualToNode(another))
 
-    def test_validChildInstance(self):
+    def test_validChildInstance(self) -> None:
         """
         Children of L{Node} instances must also be L{Node} instances.
         """
@@ -930,7 +938,7 @@ class DocumentTests(TestCase):
 
     doctype = 'foo PUBLIC "baz" "http://www.example.com/example.dtd"'
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{Document.isEqualToNode} returns C{True} if and only if passed a
         L{Document} with the same C{doctype} and C{documentElement}.
@@ -961,7 +969,7 @@ class DocumentTests(TestCase):
         document.documentElement.appendChild(microdom.Node(object()))
         self.assertFalse(document.isEqualToNode(another))
 
-    def test_childRestriction(self):
+    def test_childRestriction(self) -> None:
         """
         L{Document.appendChild} raises L{ValueError} if the document already
         has a child.
@@ -978,7 +986,7 @@ class EntityReferenceTests(TestCase):
     Tests for L{EntityReference}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{EntityReference.isEqualToNode} returns C{True} if and only if passed
         a L{EntityReference} with the same C{eref}.
@@ -1000,7 +1008,7 @@ class CharacterDataTests(TestCase):
     Tests for L{CharacterData}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{CharacterData.isEqualToNode} returns C{True} if and only if passed a
         L{CharacterData} with the same value.
@@ -1018,7 +1026,7 @@ class CommentTests(TestCase):
     Tests for L{Comment}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{Comment.isEqualToNode} returns C{True} if and only if passed a
         L{Comment} with the same value.
@@ -1032,7 +1040,7 @@ class TextTests(TestCase):
     Tests for L{Text}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{Text.isEqualToNode} returns C{True} if and only if passed a L{Text}
         which represents the same data.
@@ -1055,7 +1063,7 @@ class CDATASectionTests(TestCase):
     Tests for L{CDATASection}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{CDATASection.isEqualToNode} returns C{True} if and only if passed a
         L{CDATASection} which represents the same data.
@@ -1073,7 +1081,7 @@ class ElementTests(TestCase):
     Tests for L{Element}.
     """
 
-    def test_isEqualToNode(self):
+    def test_isEqualToNode(self) -> None:
         """
         L{Element.isEqualToNode} returns C{True} if and only if passed a
         L{Element} with the same C{nodeName}, C{namespace}, C{childNodes}, and
